@@ -5,13 +5,14 @@ class Session:
         self.app = app
         self._dict = {}
         self.lifetime = lifetime
-    
-    def __setitem__(self, key, value):
-        if self.lifetime == "session":
-            self.app.set_cookie(key, value)
-        else:
-            self.app.set_cookie(key, value, lifetime=self.lifetime)
-        self._dict[key] = value
-    
+
     def __getitem__(self, key):
-        return self._dict[key]
\ No newline at end of file
+        return self._dict[key]
+
+    def make_session(self, key, value, resp):
+        if self.lifetime == "session":
+            self.app.set_cookie(key, value, resp)
+        else:
+            self.app.set_cookie(key, value, resp, lifetime=self.lifetime)
+
+        self._dict[key] = value
